@@ -7,18 +7,21 @@
 #' @param C a numeric of the constant used in the penalty and weight inside the Gaussian kernel
 #' @return a list containing w0 and vector w used for computing weighted correlation
 #'
-#' @examples weight(t = c(0, 5, 10, 15, 20), lag = 1, C = 20)
+#' @examples
+#' weight(t = c(0, 5, 10, 15, 20), lag = 1, C = 20)
+#' weight(t = c(0, 2, 5, 10, 14, 19, 22), lag = 1,C = 100)
 #'
 #'
 #' @author Thevaa Chandereng, Anthony Gitter
 #'
+#' @export weight
 #'
 
 
 #computing weights for inside the weighted correlation and outside penalty function
 weight <- function(t, lag, C){
   #checking if all the variables are right
-  stopifnot(length(t)/4 >= lag, is.numeric(C), all(is.numeric(t)), is.numeric(lag))
+  stopifnot(length(t) / 4 >= lag, is.numeric(C), C > 0, all(is.numeric(t)), is.numeric(lag))
   #creating two rows with lagged timepoints
   tlag <- rbind(t[(lag + 1):length(t)], t[1:(length(t) - lag)])
   # w0 is the outside penalty function
